/*
 *  sydra
 *
 *  sydra is a toolbox which allows you to set up multiple bidirectional
 *  Video/Audio streams from external locations.
 *  sydra has been written to be used for the Elevate Festival in Graz
 *  Austria in order to involve external locations to present themselves
 *  at the festival.
 *
 *
 *  Copyright (C) 2014 Christian Pointner <equinox@spreadspace.org>
 *
 *  This file is part of sydra.
 *
 *  sydra is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  any later version.
 *
 *  sydra is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with sydra. If not, see <http://www.gnu.org/licenses/>.
 *
 *  In addition, as a special exception, the copyright holders hereby
 *  grant permission for non-GPL-compatible GStreamer plugins to be used
 *  and distributed together with GStreamer and sydra.
 *  This permission goes above and beyond the permissions granted by the
 *  GPL license sydra is covered by.
 */

#ifndef SYDRA_datatypes_h_INCLUDED
#define SYDRA_datatypes_h_INCLUDED

#include <stdint.h>

#include <glib.h>
#include <gio/gio.h>
#include <gst/gst.h>

#include <netdb.h>

typedef enum { SENDER, RECEIVER } sydra_rtp_mode_t;

struct addr_port {
  enum { IPv4, IPv6 } type_;
  gchar addr_[INET6_ADDRSTRLEN + 1];
  guint16 port_;
};

struct udp_client {
  struct addr_port host_;
  GstClockTime last_seen_;
};

struct udp_sink {
  GstElement *udp_;
  GList* clients_;
};

struct udp_sinks {
  struct udp_sink rtp_video_;
  struct udp_sink rtcp_video_;
  struct udp_sink rtp_audio_;
  struct udp_sink rtcp_audio_;
  int client_timeout_;
};

struct udp_sources {
  GstElement* rtp_video_;
  GstElement* rtcp_video_;
  GstElement* rtp_audio_;
  GstElement* rtcp_audio_;
  int keepalive_interval_;
  GInetAddress* remote_addr_;
  guint port_base_;
};

#endif
