/*
 *  sydra
 *
 *  sydra is a toolbox which allows you to set up multiple bidirectional
 *  Video/Audio streams from external locations.
 *  sydra has been written to be used for the Elevate Festival in Graz
 *  Austria in order to involve external locations to present themselves
 *  at the festival.
 *
 *
 *  Copyright (C) 2014 Christian Pointner <equinox@spreadspace.org>
 *
 *  This file is part of sydra.
 *
 *  sydra is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  any later version.
 *
 *  sydra is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with sydra. If not, see <http://www.gnu.org/licenses/>.
 *
 *  In addition, as a special exception, the copyright holders hereby
 *  grant permission for non-GPL-compatible GStreamer plugins to be used
 *  and distributed together with GStreamer and sydra.
 *  This permission goes above and beyond the permissions granted by the
 *  GPL license sydra is covered by.
 */

#include "datatypes.h"

#include <gst/gst.h>
#include <stdio.h>
#include <string.h>

#include "pipelines-launch.h"
#include "options-launch.h"
#include "utils.h"
#include "log.h"

GstElement* create_pipeline(options_t* opt)
{
  GError *error = NULL;
  GstElement *pipeline = gst_parse_launch(opt->pipeline_, &error);
  if(!pipeline) {
    log_printf(WARNING, "pipeline description parser: %s", error ? error->message : "unknown");
    g_error_free(error);
    return NULL;
  }
  if(error) {
    log_printf(WARNING, "pipeline description parser: %s", error ? error->message : "unknown");
    g_error_free(error);
  }

  log_printf(INFO, "pipeline created successfully!");
  return pipeline;
}
